@@ -43,6 +43,7 @@ __all__ = (
     "SessionStatusType",
     "SourceType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -355,10 +356,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -366,3 +369,12 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_datasets",
+    "list_job_runs",
+    "list_jobs",
+    "list_projects",
+    "list_recipe_versions",
+    "list_recipes",
+    "list_schedules",
+]
